@@ -1,5 +1,7 @@
 import logging
+import logging
 from typing import Dict, List, Iterable, Tuple, Any
+from typing import Dict, Tuple, List
 
 from allennlp.common.file_utils import cached_path
 from allennlp.data.dataset_readers.dataset_reader import DatasetReader
@@ -13,15 +15,10 @@ from allennlp.data.token_indexers import (
 from allennlp.data.tokenizers import Token
 from allennlp_models.common.ontonotes import Ontonotes, OntonotesSentence
 from allennlp_models.structured_prediction import SrlReader
+from conllu import parse_incr
 from overrides import overrides
 from transformers import AutoTokenizer
 
-from typing import Dict, Tuple, List
-import logging
-
-from conllu import parse_incr
-
-
 logger = logging.getLogger(__name__)
 
 """
@@ -46,57 +43,13 @@ conllu_fields = [
     "feats",
     "head",
     "deprel",
-    "is_frame",
+    "dunno",
+    "dunno2",
     "frame",
     "roles",
 ]
 
 
-def _convert_tags_to_wordpiece_tags(tags: List[str], offsets: List[int]) -> List[str]:
-    """
-    Converts a series of BIO tags to account for a wordpiece tokenizer,
-    extending/modifying BIO tags where appropriate to deal with words which
-    are split into multiple wordpieces by the tokenizer.
-
-    This is only used if you pass a `bert_model_name` to the dataset reader below.
-
-    # Parameters
-
-    tags : `List[str]`
-        The BIO formatted tags to convert to BIO tags for wordpieces
-    offsets : `List[int]`
-        The wordpiece offsets.
-
-    # Returns
-
-    The new BIO tags.
-    """
-    new_tags = []
-    j = 0
-    for i, offset in enumerate(offsets):
-        tag = tags[i]
-        is_o = tag == "O"
-        is_start = True
-        while j < offset:
-            if is_o:
-                new_tags.append("O")
-
-            elif tag.startswith("I"):
-                new_tags.append(tag)
-
-            elif is_start and tag.startswith("B"):
-                new_tags.append(tag)
-                is_start = False
-
-            elif tag.startswith("B"):
-                _, label = tag.split("-", 1)
-                new_tags.append("I-" + label)
-            j += 1
-
-    # Add O tags for cls and sep tokens.
-    return ["O"] + new_tags + ["O"]
-
-
 def _convert_verb_indices_to_wordpiece_indices(
     verb_indices: List[int], offsets: List[int], binary: bool = True
 ):
@@ -105,7 +58,7 @@ def _convert_verb_indices_to_wordpiece_indices(
     extending/modifying BIO tags where appropriate to deal with words which
     are split into multiple wordpieces by the tokenizer.
 
-    This is only used if you pass a `bert_model_name` to the dataset reader below.
+    This is only used if you pass a `model_name` to the dataset reader below.
 
     # Parameters
 
@@ -140,7 +93,7 @@ def _convert_frames_indices_to_wordpiece_indices(
     Converts frame labels to account for a wordpiece tokenizer,
     extending/modifying BIO tags where appropriate to deal with words which
     are split into multiple wordpieces by the tokenizer.
-    This is only used if you pass a `bert_model_name` to the dataset reader below.
+    This is only used if you pass a `model_name` to the dataset reader below.
     # Parameters
     frame_labels : `List[int]`
         Frame labels.
@@ -190,7 +143,7 @@ class SrlTransformersSpanReader(SrlReader):
     domain_identifier : `str`, (default = `None`)
         A string denoting a sub-domain of the Ontonotes 5.0 dataset to use. If present, only
         conll files under paths containing this domain identifier will be processed.
-    bert_model_name : `Optional[str]`, (default = `None`)
+    model_name : `Optional[str]`, (default = `None`)
         The BERT model to be wrapped. If you specify a bert_model here, then we will
         assume you want to use BERT throughout; we will use the bert tokenizer,
         and will expand your tags and verb indicators accordingly. If not,
@@ -205,17 +158,17 @@ class SrlTransformersSpanReader(SrlReader):
         self,
         token_indexers: Dict[str, TokenIndexer] = None,
         domain_identifier: str = None,
-        bert_model_name: str = None,
+        model_name: str = None,
         **kwargs,
     ) -> None:
         DatasetReader.__init__(self, **kwargs)
         self._token_indexers = token_indexers or {
-            "tokens": PretrainedTransformerIndexer(bert_model_name)
+            "tokens": PretrainedTransformerIndexer(model_name)
         }
         self._domain_identifier = domain_identifier
 
-        self.bert_tokenizer = AutoTokenizer.from_pretrained(bert_model_name)
-        self.lowercase_input = "uncased" in bert_model_name
+        self.tokenizer = AutoTokenizer.from_pretrained(model_name)
+        self.lowercase_input = "uncased" in model_name
 
     def _wordpiece_tokenize_input(
         self, tokens: List[str]
@@ -260,15 +213,13 @@ class SrlTransformersSpanReader(SrlReader):
         for token in tokens:
             if self.lowercase_input:
                 token = token.lower()
-            word_pieces = self.bert_tokenizer.tokenize(token)
+            word_pieces = self.tokenizer.tokenize(token)
             start_offsets.append(cumulative + 1)
             cumulative += len(word_pieces)
             end_offsets.append(cumulative)
             word_piece_tokens.extend(word_pieces)
 
-        wordpieces = (
-            [self.bert_tokenizer.cls_token] + word_piece_tokens + [self.bert_tokenizer.sep_token]
-        )
+        wordpieces = [self.tokenizer.cls_token] + word_piece_tokens + [self.tokenizer.sep_token]
         return wordpieces, end_offsets, start_offsets
 
     @overrides
@@ -290,10 +241,7 @@ class SrlTransformersSpanReader(SrlReader):
             if sentence.srl_frames:
                 for (_, tags) in sentence.srl_frames:
                     verb_indicator = [1 if label[-2:] == "-V" else 0 for label in tags]
-                    frames = [
-                        f if v == 1 else "O"
-                        for f, v in zip(sentence.predicate_framenet_ids, verb_indicator)
-                    ]
+                    frames = self._get_predicate_labels(sentence, verb_indicator)
                     lemmas = [
                         f for f, v in zip(sentence.predicate_lemmas, verb_indicator) if v == 1
                     ]
@@ -324,7 +272,7 @@ class SrlTransformersSpanReader(SrlReader):
         # In order to override the indexing mechanism, we need to set the `text_id`
         # attribute directly. This causes the indexing to use this id.
         text_field = TextField(
-            [Token(t, text_id=self.bert_tokenizer.vocab[t]) for t in wordpieces],
+            [Token(t, text_id=self.tokenizer.convert_tokens_to_ids(t)) for t in wordpieces],
             token_indexers=self._token_indexers,
         )
         verb_indicator = SequenceLabelField(new_verbs, text_field)
@@ -349,7 +297,7 @@ class SrlTransformersSpanReader(SrlReader):
         metadata_dict["verb_index"] = verb_index
 
         if tags:
-            new_tags = _convert_tags_to_wordpiece_tags(tags, offsets)
+            new_tags = self._convert_tags_to_wordpiece_tags(tags, offsets)
             new_frames = _convert_frames_indices_to_wordpiece_indices(frames, offsets)
             fields["tags"] = SequenceLabelField(new_tags, text_field)
             fields["frame_tags"] = SequenceLabelField(
@@ -361,8 +309,66 @@ class SrlTransformersSpanReader(SrlReader):
         fields["metadata"] = MetadataField(metadata_dict)
         return Instance(fields)
 
+    def _convert_tags_to_wordpiece_tags(self, tags: List[str], offsets: List[int]) -> List[str]:
+        """
+        Converts a series of BIO tags to account for a wordpiece tokenizer,
+        extending/modifying BIO tags where appropriate to deal with words which
+        are split into multiple wordpieces by the tokenizer.
 
-@DatasetReader.register("transformer_srl_dep")
+        This is only used if you pass a `model_name` to the dataset reader below.
+
+        # Parameters
+
+        tags : `List[str]`
+            The BIO formatted tags to convert to BIO tags for wordpieces
+        offsets : `List[int]`
+            The wordpiece offsets.
+
+        # Returns
+
+        The new BIO tags.
+        """
+        new_tags = []
+        j = 0
+        for i, offset in enumerate(offsets):
+            tag = tags[i]
+            is_o = tag == "O"
+            is_start = True
+            while j < offset:
+                if is_o:
+                    new_tags.append("O")
+
+                elif tag.startswith("I"):
+                    new_tags.append(tag)
+
+                elif is_start and tag.startswith("B"):
+                    new_tags.append(tag)
+                    is_start = False
+
+                elif tag.startswith("B"):
+                    _, label = tag.split("-", 1)
+                    new_tags.append("I-" + label)
+                j += 1
+
+        # Add O tags for cls and sep tokens.
+        return ["O"] + new_tags + ["O"]
+
+    def _get_predicate_labels(self, sentence, verb_indicator):
+        labels = []
+        for i, v in enumerate(verb_indicator):
+            if v == 1:
+                label = (
+                    "{}.{}".format(sentence.predicate_lemmas[i], sentence.predicate_framenet_ids[i])
+                    if sentence.predicate_framenet_ids[i].isdigit()
+                    else sentence.predicate_framenet_ids[i]
+                )
+                labels.append(label)
+            else:
+                labels.append("O")
+        return labels
+
+
+@DatasetReader.register("transformer_srl_dependency")
 class SrlUdpDatasetReader(SrlTransformersSpanReader):
     """
     Reads a file in the conllu Universal Dependencies format.
@@ -382,7 +388,7 @@ class SrlUdpDatasetReader(SrlTransformersSpanReader):
     def __init__(
         self, token_indexers: Dict[str, TokenIndexer] = None, model_name: str = None, **kwargs,
     ) -> None:
-        super().__init__(token_indexers=token_indexers, bert_model_name=model_name, **kwargs)
+        super().__init__(token_indexers=token_indexers, model_name=model_name, **kwargs)
 
     @overrides
     def _read(self, file_path: str):
@@ -410,42 +416,64 @@ class SrlUdpDatasetReader(SrlTransformersSpanReader):
                 if "frame" not in annotation[0] or "roles" not in annotation[0]:
                     continue
                 frames = [x["frame"] for x in annotation]
+                # clean C-V tags (not needed yet)
+                frames = [f if f != "C-V" else "_" for f in frames]
                 roles = [x["roles"] for x in annotation]
                 # transpose rolses, to have a list of roles per frame
                 roles = list(map(list, zip(*roles)))
                 current_frame = 0
                 for i, frame, in enumerate(frames):
-                    try:
-                        if frame != "_":
-                            verb_indicator = [0] * len(frames)
-                            verb_indicator[i] = 1
-                            frame_lables = ["O"] * len(frames)
-                            frame_lables[i] = frame
-                            role_labels = [
-                                "B-" + r if r != "_" else "O" for r in roles[current_frame]
-                            ]
-                            role_labels[i] = "B-V"
-                            lemma = lemmas[i]
-                            current_frame += 1
-                            yield self.text_to_instance(
-                                words, verb_indicator, frame_lables, lemma, role_labels
-                            )
-                    except:
-                        if frame != "_":
-                            print(words)
-                            print(frames)
-                            print(current_frame)
-                            print(len(roles))
-                            verb_indicator = [0] * len(frames)
-                            verb_indicator[i] = 1
-                            frame_lables = ["O"] * len(frames)
-                            frame_lables[i] = frame
-                            role_labels = [
-                                "B-" + r if r != "_" else "O" for r in roles[current_frame]
-                            ]
-                            role_labels[i] = "B-V"
-                            lemma = lemmas[i]
-                            current_frame += 1
-                            yield self.text_to_instance(
-                                words, verb_indicator, frame_lables, lemma, role_labels
-                            )
+                    if frame != "_":
+                        verb_indicator = [0] * len(frames)
+                        verb_indicator[i] = 1
+                        frame_labels = ["O"] * len(frames)
+                        frame_labels[i] = frame
+                        role_labels = ["B-" + r if r != "_" else "O" for r in roles[current_frame]]
+                        # add V tag to the verb role
+                        role_labels[i] = "B-V"
+                        lemma = lemmas[i]
+                        current_frame += 1
+                        yield self.text_to_instance(
+                            words, verb_indicator, frame_labels, lemma, role_labels
+                        )
+
+    def _convert_tags_to_wordpiece_tags(self, tags: List[str], offsets: List[int]) -> List[str]:
+        """
+        Converts a series of BIO tags to account for a wordpiece tokenizer,
+        extending/modifying BIO tags where appropriate to deal with words which
+        are split into multiple wordpieces by the tokenizer.
+
+        This is only used if you pass a `model_name` to the dataset reader below.
+
+        # Parameters
+
+        tags : `List[str]`
+            The BIO formatted tags to convert to BIO tags for wordpieces
+        offsets : `List[int]`
+            The wordpiece offsets.
+
+        # Returns
+
+        The new BIO tags.
+        """
+        new_tags = []
+        j = 0
+        for i, offset in enumerate(offsets):
+            tag = tags[i]
+            is_o = tag == "O"
+            is_start = True
+            while j < offset:
+                if is_o:
+                    new_tags.append("O")
+
+                elif is_start and tag.startswith("B"):
+                    new_tags.append(tag)
+                    is_start = False
+
+                elif tag.startswith("B"):
+                    _, label = tag.split("-", 1)
+                    new_tags.append("B-" + label)
+                j += 1
+
+        # Add O tags for cls and sep tokens.
+        return ["O"] + new_tags + ["O"]
